@@ -11,7 +11,11 @@ import json
 import pandas as pd
 import numpy as np
 import netCDF4
-import cf_units
+try:
+    import cf_units
+except ImportError:
+    # ReadTheDocs unable to pip install cf-units
+    pass
 from forest import (
         satellite,
         rdt,
@@ -22,7 +26,11 @@ import bokeh.models
 from collections import OrderedDict, defaultdict
 from functools import partial
 import scipy.ndimage
-import shapely.geometry
+try:
+    import shapely.geometry
+except ImportError:
+    # ReadTheDocs unable to pip install shapely
+    pass
 from forest.util import (
         timeout_cache,
         initial_time,
@@ -270,6 +278,7 @@ class DBLoader(object):
             "dh": [],
             "image": [],
             "name": [],
+            "units": [],
             "valid": [],
             "initial": [],
             "length": [],
@@ -308,6 +317,7 @@ class DBLoader(object):
         valid = self.to_datetime(state.valid_time)
         initial = self.to_datetime(state.initial_time)
         hours = (valid - initial).total_seconds() / (60*60)
+        units = self.read_units(path, state.variable)
         length = "T{:+}".format(int(hours))
         data = load_image_pts(
                 path,
@@ -319,12 +329,23 @@ class DBLoader(object):
         else:
             level = "Surface"
         data["name"] = [self.name]
+        data["units"] = [units]
         data["valid"] = [valid]
         data["initial"] = [initial]
         data["length"] = [length]
         data["level"] = [level]
         return data
 
+    @staticmethod
+    def read_units(filename,parameter):
+        dataset = netCDF4.Dataset(filename)
+        veep = dataset.variables[parameter]
+        # read the units and assign a blank value if there aren't any:
+        units = getattr(veep, 'units', '')
+        dataset.close()
+        return units
+
+
     def valid(self, state):
         if state.variable is None:
             return False
